@@ -1,10 +1,30 @@
+from dateutil import parser, tz
+
+TZINFOS = {
+    "EST": tz.gettz("US/Eastern"),
+    "EDT": tz.gettz("US/Eastern"),
+    "CST": tz.gettz("US/Central"),
+    "CDT": tz.gettz("US/Central"),
+    "MST": tz.gettz("US/Mountain"),
+    "MDT": tz.gettz("US/Mountain"),
+    "PST": tz.gettz("US/Pacific"),
+    "PDT": tz.gettz("US/Pacific"),
+}
+
+
 class AlchemerObject(object):
     def __init__(self, session, name, **kwargs):
         self.__name__ = name
         self.__parent = kwargs.pop("parent", None)
         self._session = getattr(self.__parent, "_session", session)
+        self._data = {}
+        self._filters = []
         self.url = f"{getattr(self.__parent, 'url', session.base_url)}/{name}"
-        self.data = {}
+
+    def _prepare_filters(self, params={}):
+        for f in self._filters:
+            params.update(f)
+        return params
 
     def get_object_data(self, id, params={}):
         self.url = f"{self.url}/{id}"
@@ -17,11 +37,18 @@ class AlchemerObject(object):
         self.data = self.get_object_data(id=id, params=params).get("data")
 
         for k, v in self.data.items():
+            try:
+                v = parser.parse(v, tzinfos=TZINFOS)
+                if not v.tzinfo and self._session.time_zone:
+                    v = v.replace(tzinfo=tz.gettz(self._session.time_zone))
+            except:
+                pass
             setattr(self, k, v)
 
         return self
 
     def list(self, params={}):
+        params = self._prepare_filters(params)
         return self._session._api_list(
             url=self.url,
             params=params,
@@ -38,6 +65,17 @@ class AlchemerObject(object):
         self.url = f"{self.url}/{id}"
         return self._session._api_call(method="DELETE", url=self.url, params={})
 
+    def filter(self, field, operator, value):
+        i = len(self._filters)
+        self._filters.append(
+            {
+                f"filter[field][{i}]": field,
+                f"filter[operator][{i}]": operator,
+                f"filter[value][{i}]": value,
+            }
+        )
+        return self
+
 
 class Survey(AlchemerObject):
     def __init__(self, **kwargs):
